@@ -1,6 +1,6 @@
 package Crypt::Bcrypt::Easy;
 {
-  $Crypt::Bcrypt::Easy::VERSION = '2.003000';
+  $Crypt::Bcrypt::Easy::VERSION = '2.003001';
 }
 use Carp;
 use strictures 1;
@@ -25,7 +25,7 @@ sub new {
   bless \$cost, $cls
 }
 
-sub cost { my ($self) = @_; $$self }
+sub cost { ${ $_[0] } }
 
 sub compare {
   my ($self, %params) = @_;
@@ -72,7 +72,6 @@ Crypt::Bcrypt::Easy - Simple interface to bcrypted passwords
 
   my $plain = 'my_password';
 
-  # Same (default cost 08):
   my $passwd = bcrypt->crypt( $plain );
   my $passwd = bcrypt->crypt( text => $plain );
   my $passwd = bcrypt->crypt( text => $plain, cost => 8 );
@@ -92,7 +91,8 @@ helpers (which were created to power L<bmkpasswd> and are a bit awkward to use
 directly).
 
 This POD briefly covers usage of this interface; 
-see L<App::bmkpasswd> for more details.
+see L<App::bmkpasswd> for more details on internals and documentation
+regarding the more flexible functional interface.
 
 This module uses L<Exporter::Tiny>; you can rename the L</bcrypt> function
 as-needed:
@@ -110,7 +110,7 @@ see L</crypt>.
 
 =head3 crypt
 
-  my $passwd = bcrypt->crypt(
+  my $crypted = bcrypt->crypt(
     text   => 'my_password',
     cost   => 8,
     strong => 0,
@@ -118,7 +118,7 @@ see L</crypt>.
 
 Or use defaults:
 
-  my $passwd = bcrypt->crypt( 'my_password' );
+  my $crypted = bcrypt->crypt( 'my_password' );
 
 Create and return a new password hash.
 
@@ -127,7 +127,7 @@ Specifying a boolean true 'strong =>' parameter enables strongly-random salts
 
 =head3 compare
 
-  if (bcrypt->compare(text => 'my_password', crypt => $passwd)) {
+  if (bcrypt->compare(text => 'my_password', crypt => $crypted)) {
      ...
   }
 
